@@ -28,11 +28,11 @@ class DApi2(object):
     
     This object is used to handle and manage the registers and commands of the DAPI2 protocol
     
-    :param DBaseCom comm: Communication channel  
+    :param DBaseCom dcom: Communication channel  
     '''
 
 
-    def __init__(self, comm, regsfile=None, dev_mode=False, errorsfie=None):
+    def __init__(self, dcom, regsfile=None, dev_mode=False, errorsfie=None):
         '''Constructor'''
         self.log = logging.getLogger(self.__class__.__name__)
         self.log.debug('Initialize')
@@ -50,7 +50,7 @@ class DApi2(object):
             errorsfie = os.path.join(os.path.dirname(__file__), 'errors.xml')        
         self.derrors = DErrorsContainer(self, errorsfie) 
         
-        self.comm = comm
+        self.dcom = dcom
         self.dev_mode = dev_mode
         
     def version(self):
@@ -66,9 +66,9 @@ class DApi2(object):
         :return The response message received from the `SLAVE`
         :rtype: BaseSlaveMessage.
         '''
-        assert self.comm.side == DApi2Side.MASTER
-        self.comm.sendMessage(msg)
-        res = self.comm.receiveMessage(msg.type())
+        assert self.dcom.side == DApi2Side.MASTER
+        self.dcom.sendMessage(msg)
+        res = self.dcom.receiveMessage(msg.type())
         if res.isError():
             self.lastErrorNo = res.getError()
         else:
