@@ -99,7 +99,10 @@ class DSerial(BaseDCom):
         self.log.info( "Serial port is open on {0!s}@{1:d}bd".format(self.serial.port, self.serial.baudrate) )
             
         
-        
+    def close(self):
+        '''Close serial port'''
+        self.log.info('Close serial to port {0!s}'.format(self.serial.port))
+        self.serial.close()
 
     def reset(self, state=DSerialState.OK):
         '''Resets the serial communications
