@@ -657,6 +657,9 @@ class BaseDBoard(object):
         self.getRegisters('setpoints', refresh=True)
         
         
+    def eepromReset(self):
+        self.dapi.cmd.factEerpomReset()
+        
     def flashFirm(self, firm, callback=None):
         
         def _readByte(x):
